%global postrel b

Name:           IBSimu
Version:        1.0.5
Release:        1.b%{?dist}
Summary:        Ion beam simulator

Group:          System Environment/Libraries
License:        GPLv2+

URL:            http://ibsimu.sourceforge.net/
Source0:        http://downloads.sourceforge.net/project/ibsimu/ibsimu/libibsimu-%{version}%{?postrel}.tar.gz

# These files were omitted from the 1.0.5b tarball.
# I had to dig them out of git. :P
Source1:	docfooter.html
Source2:	docheader.html
Source3:	docstyle.css
Source4:	main.dxy
Source5:	main_dev.dxy
Source6:	webfooter.html
Source7:	webheader.html

#These two patches allow IBSimu to be built on RHEL5. The cairo requirement is to strict
#and a gtk call can be removed since it only provides tooltips
#Both patches are reported upstream:
Patch0 :        libibsimu-lower-cairo.patch
Patch1:         libibsimu-remove-gtk_widget_set_tooltip_text.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if 0%{?rhel} == 5
BuildRequires:  cairo-devel%{?_isa}
BuildRequires:  autoconf
# Needed on RHEL but not CentOS?
BuildRequires:  automake
%else
BuildRequires:  cairo-devel%{?_isa} >= 1.4.0
%endif
BuildRequires:  zlib-devel%{?_isa}
BuildRequires:  libpng-devel%{?_isa}
BuildRequires:  fontconfig-devel%{?_isa}
BuildRequires:  freetype-devel%{?_isa}
BuildRequires:  gtk2-devel%{?_isa}
BuildRequires:  gsl-devel%{?_isa}
BuildRequires:  doxygen%{?_isa}

%if 0%{?rhel} == 5
BuildRequires: graphviz-gd
%endif

%if %{?fedora}%{!?fedora:0} >= 9
BuildRequires:  tex(latex)
%else
%if %{?rhel}%{!?rhel:0} >= 6
BuildRequires:  tex(latex)
%else
BuildRequires:  tetex-latex
%endif
%endif

%description
Ion Beam Simulator or IBSimu is an ion optical computer simulation package 
for ion optics, plasma extraction and space charge dominated ion beam
transport using Vlasov iteration. The code has several capabilities 
for solving electric fields in a defined geometry and tracking 
particles in electric and magnetic fields. The code is constructed 
as a C++ library for maximal versatility and openness.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n libibsimu-%{version}%{?postrel}
%if 0%{?rhel} == 5
%patch0 -p1
%patch1 -p1
%endif

# Copy in missing doc files
cp %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} %{SOURCE7} doc/

%build
%if 0%{?rhel} == 5
autoreconf
%endif
%configure --disable-static
make %{?_smp_mflags}
make %{?_smp_mflags} doc

%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot}
find %{buildroot} -name '*.la' -exec rm -f {} ';'

%clean
rm -rf %{buildroot}

%check
make check

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%{_libdir}/libibsimu*.so.*
%doc README COPYING

%files devel
%defattr(-,root,root,-)
%{_includedir}/ibsimu*
%{_libdir}/libibsimu*.so
%{_libdir}/pkgconfig/ibsimu*.pc
%doc doc/html

%changelog
* Wed Mar 21 2012 Tom Callaway <spot@fedoraproject.org> - 1.0.5-1.b
- update to 1.0.5b

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-7
- Rebuilt for c++ ABI breakage

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Dec 06 2011 Adam Jackson <ajax@redhat.com> - 1.0.4-5
- Rebuild for new libpng

* Mon Apr 18 2011 Steve Traylen <steve.traylen@cern.ch> 1.0.4-4
- Add automake to BR for rhel but not centos?
- define size_t with libibsimu-cstddef.patch

* Mon Apr 18 2011 Steve Traylen <steve.traylen@cern.ch> 1.0.4-3
- Correct english in descripton.

* Thu Apr 7 2011 Steve Traylen <steve.traylen@cern.ch> 1.0.4-2
- Add libibsimu-lower-cairo.patch and
  libibsimu-remove-gtk_widget_set_tooltip_text.patch to allow
  building for RHEL5.

* Wed Apr 6 2011 Steve Traylen <steve.traylen@cern.ch> 1.0.4-1
- initial build

